@@ -9,7 +9,9 @@
 #' @examples
 #' cube <- createCube()
 #' plot(cube)
-#'
+#' # using pipe
+#' require(magrittr)
+#' createCube() %>% plot()
 #' @export
 plot.cube <- function(x, ...) {
  projekt <- x$cube
@@ -25,9 +27,9 @@ plot.cube <- function(x, ...) {
         with(pkty, {
           ## Girth is diameter in inches
           symbols(col,row, squares = rep(1,times= nrow(pkty)), inches = FALSE,
-                  bg = kolory[i], fg = "black",add= TRUE)
+                  bg = kolory[i],fg = "black", add= TRUE)
         })
 
     }
-return(x)
+#return(x)
     }
